
Jupyter Notebooks examples
==========================

Within the `IS-ENES <https://is.enes.org/>`_ project, jupyter notebooks were written to show real life scenarios of
icclim usage.
The are stored within their `own repository <https://gitlab.com/is-enes-cdi-c4i/notebooks/-/tree/master>`_.

- `Averaged Temperature Anomaly 2081-2100 vs 1971-2000 SSP585 <https://gitlab.com/is-enes-cdi-c4i/notebooks/-/blob/master/C4I_Averaged_Temperature_Anomaly_2081-2100_vs_1971-2000_SSP5.ipynb>`_
- `Number of Summer Days <https://gitlab.com/is-enes-cdi-c4i/notebooks/-/blob/master/C4I_Summer_days._Calculate__subset_and_plot.ipynb>`_
- `Percentage of days when Tmax > 90th percentil (TX90p) <https://gitlab.com/is-enes-cdi-c4i/notebooks/-/blob/master/C4I_TX90p._Calculate__subset_and_plot.ipynb>`_
- `Averaged surface temperature anomaly and the same for precipitation anomaly over the period 2081-2100 compared to the period 1981-2000, and display delta-T delta-P diagram <https://gitlab.com/is-enes-cdi-c4i/notebooks/-/blob/master/C4I_deltaT_deltaP_Anomaly_2081-2100_vs_1971-2000.ipynb>`_
- `Number of days with maximum temperature above freezing <https://gitlab.com/is-enes-cdi-c4i/notebooks/-/blob/master/C4I_userindex_maxtemp_freezing.ipynb>`_
